3.1.1. pypago.sections.Section — PyPAGO 1.0.1 documentation

# 3.1.1. pypago.sections.Section

class `pypago.sections.` `Section`(name, lon, lat, dire)

  Section endpoint object.

  `__init__`(name, lon, lat, dire)

    Parameters: | name (str) – Name of the section lon (numpy.array) – Section endpoints longitudes lat (numpy.array) – Section endpoints latitudes dire (numpy.array) – Section segments directions

  Methods

  `__init__`(name, lon, lat, dire) |
  param str name: | Name of the section